@@ -313,7 +313,7 @@ class RuleConfigurationAction(argparse.Action):
             setattr(namespace, self.dest, items)
         except Exception:  # pylint: disable=W0703
             parser.print_help()
-            parser.exit()
+            parser.exit(1)
 
 
 class CliArgs:
@@ -331,7 +331,7 @@ class CliArgs:
 
             def error(self, message):
                 self.print_help(sys.stderr)
-                self.exit(32, f"{self.prog}: error: {message}\n")
+                self.exit(1, f"{self.prog}: error: {message}\n")
 
         class ExtendAction(argparse.Action):
             """Support argument types that are lists and can
@@ -515,6 +515,7 @@ class CliArgs:
         advanced.add_argument(
             "-s",
             "--registry-schemas",
+            default=[],
             help="one or more directories of CloudFormation Registry Schemas",
             action="extend",
             type=comma_separated_arg,
@@ -533,6 +534,12 @@ class CliArgs:
             help="Update the CloudFormation Specs",
             action="store_true",
         )
+        advanced.add_argument(
+            "-p",
+            "--patch-specs",
+            help="Patch the CloudFormation Specs in place",
+            action="store_true",
+        )
         advanced.add_argument(
             "--update-documentation", help=argparse.SUPPRESS, action="store_true"
         )
@@ -610,14 +617,43 @@ class ManualArgs(TypedDict, total=False):
     non_zero_exit_code: str
     output_file: str
     regions: list
+    registry_schemas: list[str]
+
+
+def _merge_configs(
+    cli_value: Any, template_value: Any, file_value: Any, manual_value: Any
+) -> Any:
+    # the CLI will always have an empty list when the item is a list
+    # we will use that to evaluate if we need to merge the lists
+    if isinstance(cli_value, list):
+        merged_list = cli_value.copy()
+        if isinstance(template_value, list):
+            merged_list.extend(template_value)
+        if isinstance(file_value, list):
+            merged_list.extend(file_value)
+        if isinstance(manual_value, list):
+            merged_list.extend(manual_value)
+        return merged_list
+
+    elif isinstance(cli_value, dict):
+        merged_dict = cli_value.copy()
+        if isinstance(template_value, dict):
+            merged_dict.update(template_value)
+        if isinstance(file_value, dict):
+            merged_dict.update(file_value)
+        if isinstance(manual_value, dict):
+            merged_dict.update(manual_value)
+        return merged_dict
+
+    return None
 
 
 # pylint: disable=too-many-public-methods
 class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs):
-    """Mixin for the Configs"""
 
     def __init__(self, cli_args: list[str] | None = None, **kwargs: Unpack[ManualArgs]):
         self._manual_args = kwargs or ManualArgs()
+        self._templates_to_process = False
         CliArgs.__init__(self, cli_args)
         # configure debug as soon as we can
         TemplateArgs.__init__(self, {})
@@ -633,6 +669,7 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs):
                 "mandatory_checks": self.mandatory_checks,
                 "include_experimental": self.include_experimental,
                 "configure_rules": self.configure_rules,
+                "registry_schemas": self.registry_schemas,
                 "regions": self.regions,
                 "ignore_bad_template": self.ignore_bad_template,
                 "debug": self.debug,
@@ -645,6 +682,7 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs):
                 "config_file": self.config_file,
                 "merge_configs": self.merge_configs,
                 "non_zero_exit_code": self.non_zero_exit_code,
+                "patch_specs": self.patch_specs,
             }
         )
 
@@ -652,27 +690,20 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs):
         cli_value = getattr(self.cli_args, arg_name)
         template_value = self.template_args.get(arg_name)
         file_value = self.file_args.get(arg_name)
+        manual_value = self._manual_args.get(arg_name)
 
         # merge list configurations
         # make sure we don't do an infinite loop so skip this check for merge_configs
         if arg_name != "merge_configs":
             if self.merge_configs:
-                # the CLI will always have an empty list when the item is a list
-                # we will use that to evaluate if we need to merge the lists
-                if isinstance(cli_value, list):
-                    # Use a copy here, otherwise we will
-                    # accumulate template level config
-                    # into the cli_value which will persist between template files
-                    result = cli_value.copy()
-                    if isinstance(template_value, list):
-                        result.extend(template_value)
-                    if isinstance(file_value, list):
-                        result.extend(file_value)
-                    return result
+                if isinstance(cli_value, (list, dict)):
+                    return _merge_configs(
+                        cli_value, template_value, file_value, manual_value
+                    )
 
         # return individual items
-        if arg_name in self._manual_args:
-            return self._manual_args[arg_name]
+        if manual_value:
+            return manual_value
         if cli_value:
             return cli_value
         if template_value and is_template:
@@ -714,7 +745,7 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs):
 
     @property
     def debug(self):
-        return self._get_argument_value("debug", False, False)
+        return self._get_argument_value("debug", False, True)
 
     @property
     def info(self):
@@ -726,23 +757,47 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs):
 
     @property
     def templates(self):
-        templates_args = self._get_argument_value("templates", False, True)
-        template_alt_args = self._get_argument_value("template_alt", False, False)
-        if template_alt_args:
-            filenames = template_alt_args
-        elif templates_args:
-            filenames = templates_args
+        """
+
+        Returns a list of Cloudformation templates to lint.
+
+        Order of precedence:
+        - Filenames provided via `-t` CLI
+        - Filenames specified in the config file.
+        - Arguments provided via `cfn-lint` CLI.
+        """
+
+        all_filenames = []
+
+        cli_alt_args = self._get_argument_value("template_alt", False, False)
+        file_args = self._get_argument_value("templates", False, True)
+        cli_args = self._get_argument_value("templates", False, False)
+
+        if cli_alt_args:
+            filenames = cli_alt_args
+        elif file_args:
+            filenames = file_args
+        elif cli_args:
+            filenames = cli_args
         else:
+            # No filenames found, could be piped in or be using the api.
             return None
 
-        # if only one is specified convert it to array
+        # If we're still haven't returned, we've got templates to lint.
+        # Build up list of templates to lint.
+        self.templates_to_process = True
+
         if isinstance(filenames, str):
             filenames = [filenames]
 
         ignore_templates = self._ignore_templates()
-        all_filenames = self._glob_filenames(filenames)
+        all_filenames.extend(self._glob_filenames(filenames))
 
-        return [i for i in all_filenames if i not in ignore_templates]
+        found_files = [i for i in all_filenames if i not in ignore_templates]
+        LOGGER.debug(
+            f"List of Cloudformation Templates to lint: {found_files} from {filenames}"
+        )
+        return found_files
 
     def _ignore_templates(self):
         ignore_template_args = self._get_argument_value("ignore_templates", False, True)
@@ -755,21 +810,23 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs):
         if isinstance(filenames, str):
             filenames = [filenames]
 
-        return self._glob_filenames(filenames)
+        return self._glob_filenames(filenames, False)
 
-    def _glob_filenames(self, filenames: Sequence[str]) -> list[str]:
+    def _glob_filenames(
+        self, filenames: Sequence[str], raise_exception: bool = True
+    ) -> list[str]:
         # handle different shells and Config files
         # some shells don't expand * and configparser won't expand wildcards
         all_filenames = []
 
         for filename in filenames:
             add_filenames = glob.glob(filename, recursive=True)
-            # only way to know of the glob failed is to test it
-            # then add the filename as requested
-            if not add_filenames:
-                all_filenames.append(filename)
-            else:
-                all_filenames.extend(add_filenames)
+
+            if not add_filenames and not self.ignore_bad_template:
+                if raise_exception:
+                    raise ValueError(f"{filename} could not be processed by glob.glob")
+
+            all_filenames.extend(add_filenames)
 
         return sorted(list(map(str, map(Path, all_filenames))))
 
@@ -792,6 +849,10 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs):
     def update_specs(self):
         return self._get_argument_value("update_specs", False, False)
 
+    @property
+    def patch_specs(self):
+        return self._get_argument_value("patch_specs", False, False)
+
     @property
     def update_documentation(self):
         return self._get_argument_value("update_documentation", False, False)
@@ -835,3 +896,11 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs):
     @property
     def force(self):
         return self._get_argument_value("force", False, False)
+
+    @property
+    def templates_to_process(self):
+        return self._templates_to_process
+
+    @templates_to_process.setter
+    def templates_to_process(self, value: bool):
+        self._templates_to_process = value
