@@ -196,8 +196,10 @@ types: list[str] = [
     "AWS::CloudFront::AnycastIpList",
     "AWS::CloudFront::CachePolicy",
     "AWS::CloudFront::CloudFrontOriginAccessIdentity",
+    "AWS::CloudFront::ConnectionGroup",
     "AWS::CloudFront::ContinuousDeploymentPolicy",
     "AWS::CloudFront::Distribution",
+    "AWS::CloudFront::DistributionTenant",
     "AWS::CloudFront::Function",
     "AWS::CloudFront::KeyGroup",
     "AWS::CloudFront::KeyValueStore",
@@ -343,11 +345,13 @@ types: list[str] = [
     "AWS::DataZone::Connection",
     "AWS::DataZone::DataSource",
     "AWS::DataZone::Domain",
+    "AWS::DataZone::DomainUnit",
     "AWS::DataZone::Environment",
     "AWS::DataZone::EnvironmentActions",
     "AWS::DataZone::EnvironmentBlueprintConfiguration",
     "AWS::DataZone::EnvironmentProfile",
     "AWS::DataZone::GroupProfile",
+    "AWS::DataZone::Owner",
     "AWS::DataZone::Project",
     "AWS::DataZone::ProjectMembership",
     "AWS::DataZone::SubscriptionTarget",
@@ -476,6 +480,7 @@ types: list[str] = [
     "AWS::EC2::VolumeAttachment",
     "AWS::ECR::PullThroughCacheRule",
     "AWS::ECR::RegistryPolicy",
+    "AWS::ECR::RegistryScanningConfiguration",
     "AWS::ECR::ReplicationConfiguration",
     "AWS::ECR::Repository",
     "AWS::ECR::RepositoryCreationTemplate",
@@ -1105,6 +1110,7 @@ types: list[str] = [
     "AWS::SSMContacts::ContactChannel",
     "AWS::SSMContacts::Plan",
     "AWS::SSMContacts::Rotation",
+    "AWS::SSMGuiConnect::Preferences",
     "AWS::SSMIncidents::ReplicationSet",
     "AWS::SSMIncidents::ResponsePlan",
     "AWS::SSMQuickSetup::ConfigurationManager",
@@ -1319,7 +1325,6 @@ cached: list[str] = [
     "aws-apigateway-documentationversion.json",
     "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
-    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -1330,10 +1335,12 @@ cached: list[str] = [
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
+    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
     "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
+    "aws-apigatewayv2-domainname.json",
     "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
@@ -1408,7 +1415,6 @@ cached: list[str] = [
     "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
     "aws-auditmanager-assessment.json",
-    "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-launchconfiguration.json",
     "aws-autoscaling-lifecyclehook.json",
     "aws-autoscaling-scalingpolicy.json",
@@ -1438,6 +1444,7 @@ cached: list[str] = [
     "aws-bedrock-flowversion.json",
     "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
+    "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
     "aws-bedrock-promptversion.json",
     "aws-budgets-budget.json",
@@ -1484,8 +1491,10 @@ cached: list[str] = [
     "aws-cloudfront-anycastiplist.json",
     "aws-cloudfront-cachepolicy.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
+    "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
     "aws-cloudfront-distribution.json",
+    "aws-cloudfront-distributiontenant.json",
     "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-keyvaluestore.json",
@@ -1615,11 +1624,13 @@ cached: list[str] = [
     "aws-datazone-connection.json",
     "aws-datazone-datasource.json",
     "aws-datazone-domain.json",
+    "aws-datazone-domainunit.json",
     "aws-datazone-environment.json",
     "aws-datazone-environmentactions.json",
     "aws-datazone-environmentblueprintconfiguration.json",
     "aws-datazone-environmentprofile.json",
     "aws-datazone-groupprofile.json",
+    "aws-datazone-owner.json",
     "aws-datazone-project.json",
     "aws-datazone-projectmembership.json",
     "aws-datazone-subscriptiontarget.json",
@@ -1743,7 +1754,6 @@ cached: list[str] = [
     "aws-ec2-verifiedaccessgroup.json",
     "aws-ec2-verifiedaccessinstance.json",
     "aws-ec2-verifiedaccesstrustprovider.json",
-    "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
     "aws-ec2-vpcblockpublicaccessexclusion.json",
@@ -1762,6 +1772,7 @@ cached: list[str] = [
     "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-pullthroughcacherule.json",
     "aws-ecr-registrypolicy.json",
+    "aws-ecr-registryscanningconfiguration.json",
     "aws-ecr-replicationconfiguration.json",
     "aws-ecr-repository.json",
     "aws-ecr-repositorycreationtemplate.json",
@@ -2000,6 +2011,7 @@ cached: list[str] = [
     "aws-kendra-index.json",
     "aws-kendraranking-executionplan.json",
     "aws-kinesis-resourcepolicy.json",
+    "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalytics-application.json",
     "aws-kinesisanalytics-applicationoutput.json",
@@ -2137,6 +2149,8 @@ cached: list[str] = [
     "aws-msk-vpcconnection.json",
     "aws-mwaa-environment.json",
     "aws-neptune-dbcluster.json",
+    "aws-neptune-dbclusterparametergroup.json",
+    "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
     "aws-neptune-eventsubscription.json",
     "aws-neptunegraph-graph.json",
@@ -2204,7 +2218,6 @@ cached: list[str] = [
     "aws-pcaconnectorad-templategroupaccesscontrolentry.json",
     "aws-pcaconnectorscep-challenge.json",
     "aws-pcaconnectorscep-connector.json",
-    "aws-pcs-cluster.json",
     "aws-pcs-computenodegroup.json",
     "aws-pcs-queue.json",
     "aws-personalize-dataset.json",
@@ -2315,7 +2328,6 @@ cached: list[str] = [
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
-    "aws-route53resolver-resolverrule.json",
     "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
@@ -2459,6 +2471,7 @@ cached: list[str] = [
     "aws-ssmcontacts-contactchannel.json",
     "aws-ssmcontacts-plan.json",
     "aws-ssmcontacts-rotation.json",
+    "aws-ssmguiconnect-preferences.json",
     "aws-ssmincidents-replicationset.json",
     "aws-ssmincidents-responseplan.json",
     "aws-sso-application.json",
@@ -2525,6 +2538,8 @@ cached: list[str] = [
     "aws-wafv2-ipset.json",
     "aws-wafv2-loggingconfiguration.json",
     "aws-wafv2-regexpatternset.json",
+    "aws-wafv2-rulegroup.json",
+    "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
     "aws-wisdom-aiagent.json",
     "aws-wisdom-aiagentversion.json",
