@@ -42,6 +42,7 @@ types: list[str] = [
     "AWS::AppConfig::Extension",
     "AWS::AppConfig::ExtensionAssociation",
     "AWS::AppConfig::HostedConfigurationVersion",
+    "AWS::AppSync::FunctionConfiguration",
     "AWS::ApplicationAutoScaling::ScalableTarget",
     "AWS::ApplicationAutoScaling::ScalingPolicy",
     "AWS::Athena::DataCatalog",
@@ -109,6 +110,7 @@ types: list[str] = [
     "AWS::Config::ConfigurationRecorder",
     "AWS::Config::DeliveryChannel",
     "AWS::Config::StoredQuery",
+    "AWS::ControlTower::EnabledBaseline",
     "AWS::DLM::LifecyclePolicy",
     "AWS::DataPipeline::Pipeline",
     "AWS::DataSync::Agent",
@@ -199,6 +201,7 @@ types: list[str] = [
     "AWS::EC2::VolumeAttachment",
     "AWS::ECR::PullThroughCacheRule",
     "AWS::ECR::RegistryPolicy",
+    "AWS::ECR::RegistryScanningConfiguration",
     "AWS::ECR::ReplicationConfiguration",
     "AWS::ECR::Repository",
     "AWS::ECR::RepositoryCreationTemplate",
@@ -224,6 +227,7 @@ types: list[str] = [
     "AWS::EMR::SecurityConfiguration",
     "AWS::EMR::Step",
     "AWS::ElastiCache::CacheCluster",
+    "AWS::ElastiCache::GlobalReplicationGroup",
     "AWS::ElastiCache::ParameterGroup",
     "AWS::ElastiCache::ReplicationGroup",
     "AWS::ElastiCache::SecurityGroup",
@@ -250,6 +254,10 @@ types: list[str] = [
     "AWS::FMS::NotificationChannel",
     "AWS::FMS::Policy",
     "AWS::FMS::ResourceSet",
+    "AWS::FSx::FileSystem",
+    "AWS::FSx::Snapshot",
+    "AWS::FSx::StorageVirtualMachine",
+    "AWS::FSx::Volume",
     "AWS::GameLift::Alias",
     "AWS::GameLift::Build",
     "AWS::GameLift::Fleet",
@@ -340,6 +348,12 @@ types: list[str] = [
     "AWS::Logs::QueryDefinition",
     "AWS::Logs::ResourcePolicy",
     "AWS::Logs::SubscriptionFilter",
+    "AWS::Logs::Transformer",
+    "AWS::MSK::BatchScramSecret",
+    "AWS::MSK::Cluster",
+    "AWS::MSK::ClusterPolicy",
+    "AWS::MSK::Configuration",
+    "AWS::MSK::VpcConnection",
     "AWS::NetworkFirewall::Firewall",
     "AWS::NetworkFirewall::FirewallPolicy",
     "AWS::NetworkFirewall::LoggingConfiguration",
@@ -388,6 +402,7 @@ types: list[str] = [
     "AWS::RedshiftServerless::Namespace",
     "AWS::RedshiftServerless::Workgroup",
     "AWS::ResourceExplorer2::DefaultViewAssociation",
+    "AWS::ResourceExplorer2::Index",
     "AWS::ResourceExplorer2::View",
     "AWS::ResourceGroups::Group",
     "AWS::RolesAnywhere::CRL",
@@ -493,7 +508,6 @@ cached: list[str] = [
     "aws-apigateway-documentationversion.json",
     "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
-    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -512,6 +526,7 @@ cached: list[str] = [
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
     "aws-appconfig-hostedconfigurationversion.json",
+    "aws-appsync-functionconfiguration.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
@@ -571,6 +586,7 @@ cached: list[str] = [
     "aws-config-configurationrecorder.json",
     "aws-config-deliverychannel.json",
     "aws-config-storedquery.json",
+    "aws-controltower-enabledbaseline.json",
     "aws-datasync-agent.json",
     "aws-datasync-locationazureblob.json",
     "aws-datasync-locationefs.json",
@@ -635,7 +651,6 @@ cached: list[str] = [
     "aws-ec2-transitgatewayroutetableassociation.json",
     "aws-ec2-transitgatewayroutetablepropagation.json",
     "aws-ec2-transitgatewayvpcattachment.json",
-    "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
     "aws-ec2-vpcblockpublicaccessexclusion.json",
@@ -654,6 +669,7 @@ cached: list[str] = [
     "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-pullthroughcacherule.json",
     "aws-ecr-registrypolicy.json",
+    "aws-ecr-registryscanningconfiguration.json",
     "aws-ecr-replicationconfiguration.json",
     "aws-ecr-repository.json",
     "aws-ecr-repositorycreationtemplate.json",
@@ -661,7 +677,6 @@ cached: list[str] = [
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
-    "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
@@ -674,6 +689,7 @@ cached: list[str] = [
     "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
+    "aws-elasticache-globalreplicationgroup.json",
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
     "aws-elasticache-securitygroupingress.json",
@@ -684,6 +700,7 @@ cached: list[str] = [
     "aws-elasticloadbalancingv2-listener.json",
     "aws-elasticloadbalancingv2-listenercertificate.json",
     "aws-elasticloadbalancingv2-listenerrule.json",
+    "aws-elasticloadbalancingv2-loadbalancer.json",
     "aws-elasticloadbalancingv2-targetgroup.json",
     "aws-elasticloadbalancingv2-truststore.json",
     "aws-elasticloadbalancingv2-truststorerevocation.json",
@@ -691,11 +708,17 @@ cached: list[str] = [
     "aws-emr-cluster.json",
     "aws-emr-instancefleetconfig.json",
     "aws-emr-instancegroupconfig.json",
+    "aws-emr-securityconfiguration.json",
     "aws-emr-step.json",
     "aws-events-eventbus.json",
     "aws-events-rule.json",
     "aws-fms-notificationchannel.json",
+    "aws-fms-policy.json",
     "aws-fms-resourceset.json",
+    "aws-fsx-filesystem.json",
+    "aws-fsx-snapshot.json",
+    "aws-fsx-storagevirtualmachine.json",
+    "aws-fsx-volume.json",
     "aws-glue-classifier.json",
     "aws-glue-connection.json",
     "aws-glue-customentitytype.json",
@@ -767,11 +790,18 @@ cached: list[str] = [
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
+    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
+    "aws-logs-transformer.json",
+    "aws-msk-batchscramsecret.json",
+    "aws-msk-cluster.json",
+    "aws-msk-clusterpolicy.json",
+    "aws-msk-configuration.json",
+    "aws-msk-vpcconnection.json",
     "aws-networkfirewall-firewall.json",
     "aws-networkfirewall-firewallpolicy.json",
     "aws-networkfirewall-loggingconfiguration.json",
@@ -779,7 +809,6 @@ cached: list[str] = [
     "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
-    "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
     "aws-opsworks-userprofile.json",
@@ -793,6 +822,7 @@ cached: list[str] = [
     "aws-ram-resourceshare.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
+    "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
     "aws-rds-dbproxy.json",
     "aws-rds-dbproxyendpoint.json",
@@ -801,6 +831,7 @@ cached: list[str] = [
     "aws-rds-dbsecuritygroupingress.json",
     "aws-rds-dbsubnetgroup.json",
     "aws-rds-eventsubscription.json",
+    "aws-rds-globalcluster.json",
     "aws-rds-optiongroup.json",
     "aws-redshift-cluster.json",
     "aws-redshift-clusterparametergroup.json",
@@ -815,6 +846,7 @@ cached: list[str] = [
     "aws-redshiftserverless-namespace.json",
     "aws-redshiftserverless-workgroup.json",
     "aws-resourceexplorer2-defaultviewassociation.json",
+    "aws-resourceexplorer2-index.json",
     "aws-resourceexplorer2-view.json",
     "aws-resourcegroups-group.json",
     "aws-rolesanywhere-crl.json",
@@ -882,6 +914,8 @@ cached: list[str] = [
     "aws-wafv2-ipset.json",
     "aws-wafv2-loggingconfiguration.json",
     "aws-wafv2-regexpatternset.json",
+    "aws-wafv2-rulegroup.json",
+    "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
     "aws-workspaces-workspace.json",
     "aws-xray-group.json",
