@@ -95,6 +95,7 @@ types: list[str] = [
     "AWS::Backup::ReportPlan",
     "AWS::BackupGateway::Hypervisor",
     "AWS::Batch::ComputeEnvironment",
+    "AWS::Batch::ConsumableResource",
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
@@ -152,6 +153,7 @@ types: list[str] = [
     "AWS::Cognito::IdentityPoolPrincipalTag",
     "AWS::Cognito::IdentityPoolRoleAttachment",
     "AWS::Cognito::LogDeliveryConfiguration",
+    "AWS::Cognito::ManagedLoginBranding",
     "AWS::Cognito::UserPool",
     "AWS::Cognito::UserPoolClient",
     "AWS::Cognito::UserPoolDomain",
@@ -324,6 +326,7 @@ types: list[str] = [
     "AWS::EC2::VerifiedAccessTrustProvider",
     "AWS::EC2::Volume",
     "AWS::EC2::VolumeAttachment",
+    "AWS::ECR::RegistryScanningConfiguration",
     "AWS::ECR::Repository",
     "AWS::ECS::CapacityProvider",
     "AWS::ECS::Cluster",
@@ -349,6 +352,7 @@ types: list[str] = [
     "AWS::EMR::Studio",
     "AWS::EMR::StudioSessionMapping",
     "AWS::EMRContainers::VirtualCluster",
+    "AWS::EMRServerless::Application",
     "AWS::ElastiCache::CacheCluster",
     "AWS::ElastiCache::GlobalReplicationGroup",
     "AWS::ElastiCache::ParameterGroup",
@@ -431,8 +435,10 @@ types: list[str] = [
     "AWS::GuardDuty::Detector",
     "AWS::GuardDuty::Filter",
     "AWS::GuardDuty::IPSet",
+    "AWS::GuardDuty::MalwareProtectionPlan",
     "AWS::GuardDuty::Master",
     "AWS::GuardDuty::Member",
+    "AWS::GuardDuty::PublishingDestination",
     "AWS::GuardDuty::ThreatIntelSet",
     "AWS::IAM::AccessKey",
     "AWS::IAM::Group",
@@ -471,6 +477,7 @@ types: list[str] = [
     "AWS::IoT::CACertificate",
     "AWS::IoT::Certificate",
     "AWS::IoT::CertificateProvider",
+    "AWS::IoT::Command",
     "AWS::IoT::CustomMetric",
     "AWS::IoT::Dimension",
     "AWS::IoT::FleetMetric",
@@ -539,6 +546,9 @@ types: list[str] = [
     "AWS::Lambda::Permission",
     "AWS::Lambda::Version",
     "AWS::LaunchWizard::Deployment",
+    "AWS::Lex::BotAlias",
+    "AWS::Lex::BotVersion",
+    "AWS::Lex::ResourcePolicy",
     "AWS::LicenseManager::Grant",
     "AWS::LicenseManager::License",
     "AWS::Location::GeofenceCollection",
@@ -566,6 +576,11 @@ types: list[str] = [
     "AWS::MSK::ClusterPolicy",
     "AWS::MSK::Configuration",
     "AWS::MSK::VpcConnection",
+    "AWS::MemoryDB::ACL",
+    "AWS::MemoryDB::Cluster",
+    "AWS::MemoryDB::ParameterGroup",
+    "AWS::MemoryDB::SubnetGroup",
+    "AWS::MemoryDB::User",
     "AWS::Neptune::DBCluster",
     "AWS::Neptune::DBClusterParameterGroup",
     "AWS::Neptune::DBInstance",
@@ -587,6 +602,7 @@ types: list[str] = [
     "AWS::Oam::Sink",
     "AWS::OpenSearchServerless::AccessPolicy",
     "AWS::OpenSearchServerless::Collection",
+    "AWS::OpenSearchServerless::Index",
     "AWS::OpenSearchServerless::LifecyclePolicy",
     "AWS::OpenSearchServerless::SecurityConfig",
     "AWS::OpenSearchServerless::SecurityPolicy",
@@ -672,8 +688,10 @@ types: list[str] = [
     "AWS::RolesAnywhere::CRL",
     "AWS::RolesAnywhere::Profile",
     "AWS::RolesAnywhere::TrustAnchor",
+    "AWS::Route53::DNSSEC",
     "AWS::Route53::HealthCheck",
     "AWS::Route53::HostedZone",
+    "AWS::Route53::KeySigningKey",
     "AWS::Route53::RecordSet",
     "AWS::Route53::RecordSetGroup",
     "AWS::Route53Profiles::Profile",
@@ -811,6 +829,7 @@ types: list[str] = [
     "AWS::Transfer::Profile",
     "AWS::Transfer::Server",
     "AWS::Transfer::User",
+    "AWS::Transfer::WebApp",
     "AWS::Transfer::Workflow",
     "AWS::VerifiedPermissions::IdentitySource",
     "AWS::VerifiedPermissions::Policy",
@@ -868,8 +887,18 @@ cached: list[str] = [
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
+    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
+    "aws-apigatewayv2-apimapping.json",
+    "aws-apigatewayv2-authorizer.json",
+    "aws-apigatewayv2-deployment.json",
+    "aws-apigatewayv2-domainname.json",
+    "aws-apigatewayv2-integrationresponse.json",
+    "aws-apigatewayv2-model.json",
+    "aws-apigatewayv2-route.json",
+    "aws-apigatewayv2-routeresponse.json",
     "aws-apigatewayv2-stage.json",
+    "aws-apigatewayv2-vpclink.json",
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
@@ -899,17 +928,20 @@ cached: list[str] = [
     "aws-appstream-stackfleetassociation.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
+    "aws-athena-datacatalog.json",
     "aws-athena-namedquery.json",
     "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
     "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-warmpool.json",
+    "aws-backup-backupplan.json",
     "aws-backup-backupselection.json",
     "aws-backup-backupvault.json",
     "aws-backup-framework.json",
     "aws-backup-reportplan.json",
     "aws-backupgateway-hypervisor.json",
     "aws-batch-computeenvironment.json",
+    "aws-batch-consumableresource.json",
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
@@ -922,6 +954,8 @@ cached: list[str] = [
     "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
     "aws-bedrock-knowledgebase.json",
+    "aws-bedrock-prompt.json",
+    "aws-bedrock-promptversion.json",
     "aws-cassandra-keyspace.json",
     "aws-cassandra-table.json",
     "aws-cassandra-type.json",
@@ -955,17 +989,19 @@ cached: list[str] = [
     "aws-codedeploy-application.json",
     "aws-codedeploy-deploymentconfig.json",
     "aws-codedeploy-deploymentgroup.json",
-    "aws-codepipeline-pipeline.json",
     "aws-codepipeline-webhook.json",
     "aws-cognito-identitypool.json",
     "aws-cognito-identitypoolprincipaltag.json",
     "aws-cognito-identitypoolroleattachment.json",
     "aws-cognito-logdeliveryconfiguration.json",
+    "aws-cognito-managedloginbranding.json",
     "aws-cognito-userpool.json",
     "aws-cognito-userpoolclient.json",
+    "aws-cognito-userpooldomain.json",
     "aws-cognito-userpoolgroup.json",
     "aws-cognito-userpoolidentityprovider.json",
     "aws-cognito-userpoolresourceserver.json",
+    "aws-cognito-userpoolriskconfigurationattachment.json",
     "aws-cognito-userpooluicustomizationattachment.json",
     "aws-cognito-userpooluser.json",
     "aws-cognito-userpoolusertogroupattachment.json",
@@ -1034,6 +1070,7 @@ cached: list[str] = [
     "aws-docdb-dbinstance.json",
     "aws-docdb-dbsubnetgroup.json",
     "aws-docdb-eventsubscription.json",
+    "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
@@ -1100,13 +1137,15 @@ cached: list[str] = [
     "aws-ec2-transitgatewayroutetableassociation.json",
     "aws-ec2-transitgatewayroutetablepropagation.json",
     "aws-ec2-transitgatewayvpcattachment.json",
+    "aws-ec2-verifiedaccessendpoint.json",
     "aws-ec2-verifiedaccessgroup.json",
-    "aws-ec2-volume.json",
+    "aws-ec2-verifiedaccessinstance.json",
+    "aws-ec2-verifiedaccesstrustprovider.json",
     "aws-ec2-vpc.json",
     "aws-ec2-vpcblockpublicaccessexclusion.json",
     "aws-ec2-vpcblockpublicaccessoptions.json",
+    "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
-    "aws-ec2-vpcendpoint.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
     "aws-ec2-vpcendpointservice.json",
     "aws-ec2-vpcendpointservicepermissions.json",
@@ -1115,12 +1154,12 @@ cached: list[str] = [
     "aws-ec2-vpnconnectionroute.json",
     "aws-ec2-vpngateway.json",
     "aws-ec2-vpngatewayroutepropagation.json",
+    "aws-ecr-registryscanningconfiguration.json",
     "aws-ecr-repository.json",
     "aws-ecs-capacityprovider.json",
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
-    "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
@@ -1150,8 +1189,9 @@ cached: list[str] = [
     "aws-emr-cluster.json",
     "aws-emr-instancefleetconfig.json",
     "aws-emr-instancegroupconfig.json",
+    "aws-emr-step.json",
     "aws-emrcontainers-virtualcluster.json",
-    "aws-events-archive.json",
+    "aws-emrserverless-application.json",
     "aws-events-eventbuspolicy.json",
     "aws-eventschemas-discoverer.json",
     "aws-eventschemas-registry.json",
@@ -1164,6 +1204,7 @@ cached: list[str] = [
     "aws-fsx-storagevirtualmachine.json",
     "aws-fsx-volume.json",
     "aws-glue-classifier.json",
+    "aws-glue-connection.json",
     "aws-glue-crawler.json",
     "aws-glue-customentitytype.json",
     "aws-glue-datacatalogencryptionsettings.json",
@@ -1200,11 +1241,14 @@ cached: list[str] = [
     "aws-guardduty-detector.json",
     "aws-guardduty-filter.json",
     "aws-guardduty-ipset.json",
+    "aws-guardduty-malwareprotectionplan.json",
     "aws-guardduty-master.json",
     "aws-guardduty-member.json",
+    "aws-guardduty-publishingdestination.json",
     "aws-guardduty-threatintelset.json",
     "aws-iam-accesskey.json",
     "aws-iam-grouppolicy.json",
+    "aws-iam-managedpolicy.json",
     "aws-iam-oidcprovider.json",
     "aws-iam-role.json",
     "aws-iam-rolepolicy.json",
@@ -1231,6 +1275,7 @@ cached: list[str] = [
     "aws-iot-cacertificate.json",
     "aws-iot-certificate.json",
     "aws-iot-certificateprovider.json",
+    "aws-iot-command.json",
     "aws-iot-custommetric.json",
     "aws-iot-dimension.json",
     "aws-iot-fleetmetric.json",
@@ -1256,9 +1301,9 @@ cached: list[str] = [
     "aws-iotevents-input.json",
     "aws-iotsitewise-accesspolicy.json",
     "aws-iotsitewise-asset.json",
-    "aws-iotsitewise-assetmodel.json",
     "aws-iotsitewise-dashboard.json",
     "aws-iotsitewise-gateway.json",
+    "aws-iotsitewise-portal.json",
     "aws-iotsitewise-project.json",
     "aws-iottwinmaker-componenttype.json",
     "aws-iottwinmaker-entity.json",
@@ -1289,6 +1334,9 @@ cached: list[str] = [
     "aws-lambda-function.json",
     "aws-lambda-permission.json",
     "aws-launchwizard-deployment.json",
+    "aws-lex-botalias.json",
+    "aws-lex-botversion.json",
+    "aws-lex-resourcepolicy.json",
     "aws-licensemanager-grant.json",
     "aws-licensemanager-license.json",
     "aws-location-geofencecollection.json",
@@ -1302,7 +1350,6 @@ cached: list[str] = [
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
-    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
@@ -1311,12 +1358,19 @@ cached: list[str] = [
     "aws-m2-application.json",
     "aws-m2-deployment.json",
     "aws-m2-environment.json",
+    "aws-memorydb-acl.json",
+    "aws-memorydb-cluster.json",
+    "aws-memorydb-parametergroup.json",
+    "aws-memorydb-subnetgroup.json",
+    "aws-memorydb-user.json",
     "aws-msk-batchscramsecret.json",
     "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
     "aws-msk-configuration.json",
     "aws-msk-vpcconnection.json",
     "aws-neptune-dbcluster.json",
+    "aws-neptune-dbclusterparametergroup.json",
+    "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
     "aws-networkfirewall-firewall.json",
     "aws-networkfirewall-firewallpolicy.json",
@@ -1334,7 +1388,9 @@ cached: list[str] = [
     "aws-oam-sink.json",
     "aws-opensearchserverless-accesspolicy.json",
     "aws-opensearchserverless-collection.json",
+    "aws-opensearchserverless-index.json",
     "aws-opensearchserverless-lifecyclepolicy.json",
+    "aws-opensearchserverless-securityconfig.json",
     "aws-opensearchserverless-securitypolicy.json",
     "aws-opensearchserverless-vpcendpoint.json",
     "aws-opsworks-app.json",
@@ -1368,6 +1424,7 @@ cached: list[str] = [
     "aws-quicksight-analysis.json",
     "aws-quicksight-custompermissions.json",
     "aws-quicksight-dashboard.json",
+    "aws-quicksight-dataset.json",
     "aws-quicksight-datasource.json",
     "aws-quicksight-folder.json",
     "aws-quicksight-refreshschedule.json",
@@ -1379,6 +1436,7 @@ cached: list[str] = [
     "aws-rbin-rule.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
+    "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
     "aws-rds-dbsecuritygroup.json",
     "aws-rds-dbsecuritygroupingress.json",
@@ -1386,13 +1444,10 @@ cached: list[str] = [
     "aws-rds-eventsubscription.json",
     "aws-rds-optiongroup.json",
     "aws-redshift-cluster.json",
-    "aws-redshift-clusterparametergroup.json",
     "aws-redshift-clustersecuritygroup.json",
     "aws-redshift-clustersecuritygroupingress.json",
-    "aws-redshift-clustersubnetgroup.json",
     "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
-    "aws-redshift-eventsubscription.json",
     "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
     "aws-redshiftserverless-workgroup.json",
@@ -1407,7 +1462,9 @@ cached: list[str] = [
     "aws-rolesanywhere-crl.json",
     "aws-rolesanywhere-profile.json",
     "aws-rolesanywhere-trustanchor.json",
+    "aws-route53-dnssec.json",
     "aws-route53-hostedzone.json",
+    "aws-route53-keysigningkey.json",
     "aws-route53-recordset.json",
     "aws-route53-recordsetgroup.json",
     "aws-route53profiles-profile.json",
@@ -1420,12 +1477,12 @@ cached: list[str] = [
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
-    "aws-route53resolver-resolverrule.json",
     "aws-route53resolver-resolverruleassociation.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
     "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
+    "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
     "aws-s3-storagelensgroup.json",
     "aws-s3objectlambda-accesspoint.json",
@@ -1507,11 +1564,13 @@ cached: list[str] = [
     "aws-sqs-queue.json",
     "aws-sqs-queuepolicy.json",
     "aws-ssm-association.json",
+    "aws-ssm-document.json",
     "aws-ssm-maintenancewindow.json",
     "aws-ssm-maintenancewindowtarget.json",
     "aws-ssm-maintenancewindowtask.json",
     "aws-ssm-parameter.json",
     "aws-ssm-patchbaseline.json",
+    "aws-ssm-resourcedatasync.json",
     "aws-ssm-resourcepolicy.json",
     "aws-sso-application.json",
     "aws-sso-applicationassignment.json",
@@ -1534,6 +1593,7 @@ cached: list[str] = [
     "aws-transfer-profile.json",
     "aws-transfer-server.json",
     "aws-transfer-user.json",
+    "aws-transfer-webapp.json",
     "aws-transfer-workflow.json",
     "aws-verifiedpermissions-identitysource.json",
     "aws-verifiedpermissions-policy.json",
